@@ -7,10 +7,11 @@ Command to list YellowDog entities.
 from typing import List
 
 from requests import HTTPError
+from yellowdog_client.common import SearchClient
 from yellowdog_client.model import (
     ComputeRequirement,
+    ComputeRequirementSearch,
     ComputeRequirementStatus,
-    ComputeRequirementSummary,
     ObjectPath,
     ObjectPathsRequest,
     Task,
@@ -80,8 +81,10 @@ def list_work_requirements():
     options chosen.
     """
     print_log(
-        f"Listing Work Requirements in 'namespace={CONFIG_COMMON.namespace}' "
-        f"and names starting with 'tag={CONFIG_COMMON.name_tag}'",
+        (
+            f"Listing Work Requirements in 'namespace={CONFIG_COMMON.namespace}' "
+            f"and names starting with 'tag={CONFIG_COMMON.name_tag}'"
+        ),
         override_quiet=True,
     )
     exclude_filter = (
@@ -93,13 +96,13 @@ def list_work_requirements():
         if ARGS_PARSER.live_only
         else []
     )
-    work_requirement_summaries: List[
-        WorkRequirementSummary
-    ] = get_filtered_work_requirements(
-        CLIENT,
-        namespace=CONFIG_COMMON.namespace,
-        tag=CONFIG_COMMON.name_tag,
-        exclude_filter=exclude_filter,
+    work_requirement_summaries: List[WorkRequirementSummary] = (
+        get_filtered_work_requirements(
+            CLIENT,
+            namespace=CONFIG_COMMON.namespace,
+            tag=CONFIG_COMMON.name_tag,
+            exclude_filter=exclude_filter,
+        )
     )
     work_requirement_summaries = sorted_objects(work_requirement_summaries)
     if not (ARGS_PARSER.task_groups or ARGS_PARSER.tasks):
@@ -141,23 +144,27 @@ def list_object_paths():
         f"Listing Object Paths in namespace '{CONFIG_COMMON.namespace}' and "
         f"names starting with '{CONFIG_COMMON.name_tag}'"
     )
-    object_paths: List[
-        ObjectPath
-    ] = CLIENT.object_store_client.get_namespace_object_paths(
-        ObjectPathsRequest(CONFIG_COMMON.namespace)
+    object_paths: List[ObjectPath] = (
+        CLIENT.object_store_client.get_namespace_object_paths(
+            ObjectPathsRequest(
+                CONFIG_COMMON.namespace,
+                prefix=CONFIG_COMMON.name_tag,
+                flat=ARGS_PARSER.object_tree,
+            )
+        )
     )
-    print_numbered_object_list(CLIENT, object_paths)
+    print_numbered_object_list(CLIENT, sorted_objects(object_paths))
 
 
 def list_worker_pools():
     print_log(
-        f"Listing Provisioned Worker Pools with Compute Requirements in "
+        "Listing Provisioned Worker Pools with Compute Requirements in "
         f"namespace '{CONFIG_COMMON.namespace}' and "
         f"names starting with '{CONFIG_COMMON.name_tag}'"
     )
-    worker_pool_summaries: List[
-        WorkerPoolSummary
-    ] = CLIENT.worker_pool_client.find_all_worker_pools()
+    worker_pool_summaries: List[WorkerPoolSummary] = (
+        CLIENT.worker_pool_client.find_all_worker_pools()
+    )
 
     selected_worker_pool_summaries: List[WorkerPoolSummary] = []
     excluded_states = (
@@ -198,33 +205,39 @@ def list_worker_pools():
 
 def list_compute_requirements():
     print_log(
-        f"Listing Compute Requirements in "
+        "Listing Compute Requirements in "
         f"namespace '{CONFIG_COMMON.namespace}' and "
         f" names starting with '{CONFIG_COMMON.name_tag}'"
     )
 
-    compute_requirement_summaries: List[
-        ComputeRequirementSummary
-    ] = CLIENT.compute_client.find_all_compute_requirements()
+    cr_search = ComputeRequirementSearch(
+        namespace=CONFIG_COMMON.namespace,
+    )
+    search_client: SearchClient = CLIENT.compute_client.get_compute_requirements(
+        cr_search
+    )
+    compute_requirements: List[ComputeRequirement] = search_client.list_all()
 
-    filtered_compute_requirement_summaries: List[ComputeRequirementSummary] = []
+    filtered_compute_requirements: List[ComputeRequirement] = []
     excluded_states = (
         [ComputeRequirementStatus.TERMINATED, ComputeRequirementStatus.TERMINATING]
         if ARGS_PARSER.live_only
         else []
     )
-    for compute_summary in compute_requirement_summaries:
-        compute_summary.tag = "" if compute_summary.tag is None else compute_summary.tag
+    for compute_requirement in compute_requirements:
+        compute_requirement.tag = (
+            "" if compute_requirement.tag is None else compute_requirement.tag
+        )
         if (
-            compute_summary.tag.startswith(CONFIG_COMMON.name_tag)
-            and compute_summary.namespace == CONFIG_COMMON.namespace
-            and compute_summary.status not in excluded_states
+            compute_requirement.tag.startswith(CONFIG_COMMON.name_tag)
+            and compute_requirement.namespace == CONFIG_COMMON.namespace
+            and compute_requirement.status not in excluded_states
         ):
-            filtered_compute_requirement_summaries.append(compute_summary)
+            filtered_compute_requirements.append(compute_requirement)
 
     print_numbered_object_list(
         CLIENT,
-        sorted_objects(filtered_compute_requirement_summaries),
+        sorted_objects(filtered_compute_requirements),
         override_quiet=True,
     )
 
