@@ -4,6 +4,7 @@ Utility functions for use with the submit command.
 
 import re
 from dataclasses import dataclass
+from glob import glob
 from typing import List, Optional
 
 from yellowdog_client import PlatformClient
@@ -40,6 +41,7 @@ def generate_task_input(
     and relative to the directory specific to this Work Requirement.
     """
     namespace, filepath = get_namespace_and_filepath(file, wr_name)
+    filepath = filepath.lstrip("/")
     if namespace is None:
         return TaskInput.from_task_namespace(
             object_name_pattern=filepath, verification=verification
@@ -85,7 +87,6 @@ def get_namespace_and_filepath(
 @dataclass
 class UploadedFile:
     local_file_path: str
-    specified_upload_path: str
     upload_namespace: str
     uploaded_file_path: str
 
@@ -105,50 +106,87 @@ class UploadedFiles:
     def add_upload_file(self, upload_file: str, upload_path: str):
         """
         Upload a file if it hasn't already been uploaded to the same location.
+        Handle wildcards.
         """
-        if ARGS_PARSER.dry_run:
-            return
 
-        if upload_file in [
-            f.local_file_path for f in self._uploaded_files
-        ] and upload_path in [f.specified_upload_path for f in self._uploaded_files]:
-            return
+        # Handle wildcard expansion
+        expanded_files = glob(pathname=upload_file, recursive=True)
+        if len(expanded_files) > 1:
+            if not upload_path.endswith("*"):
+                raise Exception(
+                    "'uploadPath' must end in '*' when using'uploadFiles' wildcards"
+                )
 
-        namespace, uploaded_file_path = get_namespace_and_filepath(
-            upload_path, self._wr_name
-        )
-        namespace = self._config.namespace if namespace is None else namespace
-        upload_file_core(
-            client=self._client,
-            url=self._config.url,
-            local_file=upload_file,
-            namespace=namespace,
-            remote_file=uploaded_file_path,
-        )
-
-        self._uploaded_files.append(
-            UploadedFile(
-                local_file_path=upload_file,
-                specified_upload_path=upload_path,
-                upload_namespace=namespace,
-                uploaded_file_path=uploaded_file_path,
+        for upload_file in expanded_files:
+            namespace, uploaded_file_path = get_namespace_and_filepath(
+                upload_path, self._wr_name
             )
-        )
+            namespace = self._config.namespace if namespace is None else namespace
 
-    def add_input_file(self, filename: str, flatten_upload_paths: bool):
+            # Adjust upload file path for a wildcard upload
+            if "*" in uploaded_file_path:
+                uploaded_file_path = uploaded_file_path.replace(
+                    "*", upload_file.split("/")[-1]
+                )
+
+            uploaded_file_path = uploaded_file_path.lstrip("/")
+
+            duplicate = False
+            for uploaded_file in self._uploaded_files:
+                if (
+                    upload_file == uploaded_file.local_file_path
+                    and uploaded_file_path == uploaded_file.uploaded_file_path
+                    and namespace == uploaded_file.upload_namespace
+                ):
+                    duplicate = True
+                    break
+            if duplicate:
+                continue
+
+            if not ARGS_PARSER.dry_run:
+                upload_file_core(
+                    client=self._client,
+                    url=self._config.url,
+                    local_file=upload_file,
+                    namespace=namespace,
+                    remote_file=uploaded_file_path,
+                )
+            else:
+                print_log(
+                    f"Dry-run: Would upload '{upload_file}' to"
+                    f" '{namespace}::{uploaded_file_path}'"
+                )
+
+            self._uploaded_files.append(
+                UploadedFile(
+                    local_file_path=upload_file,
+                    upload_namespace=namespace,
+                    uploaded_file_path=uploaded_file_path,
+                )
+            )
+
+    def add_input_file(self, filename: str, flatten_upload_paths: bool) -> List[str]:
         """
-        Add a file from the inputs list.
+        Add a filename from the inputs list, processing wildcards if present.
+        Return the expanded list of filenames.
         """
-        # Apply Work Requirement name prefix, etc.
-        upload_file_name = unique_upload_pathname(
-            filename=filename,
-            id=self._wr_name,
-            inputs_folder_name=None,
-            urlencode_forward_slash=False,
-            flatten_upload_paths=flatten_upload_paths,
-        )
-        # Force 'uploaded_file_name' to be at the root of the namespace
-        self.add_upload_file(filename, f"{NAMESPACE_SEPARATOR}{upload_file_name}")
+
+        # Expand wildcards
+        expanded_files = glob(pathname=filename, recursive=True)
+
+        for filename in expanded_files:
+            # Apply Work Requirement name prefix, etc.
+            upload_file_name = unique_upload_pathname(
+                filename=filename,
+                id=self._wr_name,
+                inputs_folder_name=None,
+                urlencode_forward_slash=False,
+                flatten_upload_paths=flatten_upload_paths,
+            )
+            # Force 'uploaded_file_name' to be at the root of the namespace
+            self.add_upload_file(filename, f"{NAMESPACE_SEPARATOR}{upload_file_name}")
+
+        return expanded_files
 
     def delete(self):
         """
@@ -181,4 +219,7 @@ def format_yd_name(yd_name: str) -> str:
     # Make obvious substitutions
     yd_name = yd_name.replace("/", "-").replace(" ", "_").lower()
     # Enforce acceptable regex and name length
-    return re.sub("[^a-z0-9_-]", "", yd_name)[:60]
+    yd_name = re.sub("[^a-z0-9_-]", "", yd_name)
+    if not yd_name[0].isalpha():
+        yd_name = f"yd_{yd_name}"
+    return yd_name[:60]
